aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNikhil Raj <nikhil.raj@arm.com>2020-08-14 12:10:39 +0100
committerTeresaARM <teresa.charlinreyes@arm.com>2020-08-17 15:37:59 +0000
commit313c99f9a64c7fc51dc70757bffff3088c2e95cf (patch)
tree6d973164f9ae437684507f1fd9f12b4e8b85991c
parent3674f1459664f69eaaaae45fe463237835a93d71 (diff)
downloadarmnn-313c99f9a64c7fc51dc70757bffff3088c2e95cf.tar.gz
IVGCVSW-4813 Update semantic versioning of ArmNN to 22.0.0 for 20.08 release
Signed-off-by: Nikhil Raj <nikhil.raj@arm.com> Change-Id: Ida6100eb62c46971b6958addfc69f15eb0634ba2
-rw-r--r--include/armnn/Version.hpp2
-rw-r--r--python/pyarmnn/README.md14
-rw-r--r--python/pyarmnn/src/pyarmnn/_version.py4
-rw-r--r--python/pyarmnn/test/test_setup.py8
-rw-r--r--python/pyarmnn/test/test_version.py4
5 files changed, 16 insertions, 16 deletions
diff --git a/include/armnn/Version.hpp b/include/armnn/Version.hpp
index a71a3fa0ff..afdc075529 100644
--- a/include/armnn/Version.hpp
+++ b/include/armnn/Version.hpp
@@ -10,7 +10,7 @@
#define STRINGIFY_MACRO(s) #s
// ArmNN version components
-#define ARMNN_MAJOR_VERSION 21
+#define ARMNN_MAJOR_VERSION 22
#define ARMNN_MINOR_VERSION 0
#define ARMNN_PATCH_VERSION 0
diff --git a/python/pyarmnn/README.md b/python/pyarmnn/README.md
index 4e7311fdac..9ccf34d218 100644
--- a/python/pyarmnn/README.md
+++ b/python/pyarmnn/README.md
@@ -91,14 +91,14 @@ This step will put all generated files under `./src/pyarmnn/_generated` folder a
```bash
$ python setup.py sdist
```
-As the result you will get `./dist/pyarmnn-21.0.0.tar.gz` file. As you can see it is platform independent.
+As the result you will get `./dist/pyarmnn-22.0.0.tar.gz` file. As you can see it is platform independent.
##### 5. Build the binary package
```bash
$ python setup.py bdist_wheel
```
-As the result you will get something like `./dist/pyarmnn-21.0.0-cp36-cp36m-linux_x86_64.whl` file. As you can see it is platform dependent.
+As the result you will get something like `./dist/pyarmnn-22.0.0-cp36-cp36m-linux_x86_64.whl` file. As you can see it is platform dependent.
# PyArmNN installation
@@ -106,8 +106,8 @@ PyArmNN can be distributed as a source package or a binary package (wheel).
Binary package is platform dependent, the name of the package will indicate the platform it was built for, e.g.:
-* Linux x86 64bit machine: pyarmnn-21.0.0-cp36-cp36m-*linux_x86_64*.whl
-* Linux Aarch 64 bit machine: pyarmnn-21.0.0-cp36-cp36m-*linux_aarch64*.whl
+* Linux x86 64bit machine: pyarmnn-22.0.0-cp36-cp36m-*linux_x86_64*.whl
+* Linux Aarch 64 bit machine: pyarmnn-22.0.0-cp36-cp36m-*linux_aarch64*.whl
The source package is platform independent but installation involves compilation of Arm NN python extension. You will need to have g++ compatible with C++ 14 standard and a python development library installed on the build machine.
@@ -125,7 +125,7 @@ $ gcc --print-search-dirs
```
Install PyArmNN from binary by pointing to the wheel file:
```bash
-$ pip install /path/to/pyarmnn-21.0.0-cp36-cp36m-linux_aarch64.whl
+$ pip install /path/to/pyarmnn-22.0.0-cp36-cp36m-linux_aarch64.whl
```
## Installing from source package
@@ -142,7 +142,7 @@ $ export ARMNN_INCLUDE=/path/to/headers
Install PyArmNN as follows:
```bash
-$ pip install /path/to/pyarmnn-21.0.0.tar.gz
+$ pip install /path/to/pyarmnn-22.0.0.tar.gz
```
If PyArmNN installation script fails to find Arm NN libraries it will raise an error like this
@@ -156,7 +156,7 @@ $ pip show pyarmnn
You can also verify it by running the following and getting output similar to below:
```bash
$ python -c "import pyarmnn as ann;print(ann.GetVersion())"
-'21.0.0'
+'22.0.0'
```
# PyArmNN API overview
diff --git a/python/pyarmnn/test/test_setup.py b/python/pyarmnn/test/test_setup.py
index d1e6e0f472..e7f98c7689 100644
--- a/python/pyarmnn/test/test_setup.py
+++ b/python/pyarmnn/test/test_setup.py
@@ -87,15 +87,15 @@ def test_gcc_serch_path():
def test_armnn_version():
- check_armnn_version('21.0.0', '21.0.0')
+ check_armnn_version('22.0.0', '22.0.0')
def test_incorrect_armnn_version():
with pytest.raises(AssertionError) as err:
- check_armnn_version('21.0.0', '21.1.0')
+ check_armnn_version('22.0.0', '22.1.0')
- assert 'Expected ArmNN version is 21.1.0 but installed ArmNN version is 21.0.0' in str(err.value)
+ assert 'Expected ArmNN version is 22.1.0 but installed ArmNN version is 22.0.0' in str(err.value)
def test_armnn_version_patch_does_not_matter():
- check_armnn_version('21.0.0', '21.0.1')
+ check_armnn_version('22.0.0', '22.0.1')
diff --git a/python/pyarmnn/test/test_version.py b/python/pyarmnn/test/test_version.py
index 14a91540fc..a212ff10c8 100644
--- a/python/pyarmnn/test/test_version.py
+++ b/python/pyarmnn/test/test_version.py
@@ -18,7 +18,7 @@ def test_dev_version():
importlib.reload(v)
- assert "21.0.0.dev1" == v.__version__
+ assert "22.0.0.dev1" == v.__version__
del os.environ["PYARMNN_DEV_VER"]
del v
@@ -30,7 +30,7 @@ def test_arm_version_not_affected():
importlib.reload(v)
- assert "21.0.0" == v.__arm_ml_version__
+ assert "22.0.0" == v.__arm_ml_version__
del os.environ["PYARMNN_DEV_VER"]
del v
diff --git a/python/pyarmnn/src/pyarmnn/_version.py b/python/pyarmnn/src/pyarmnn/_version.py
index e79724854c..c60d4dd088 100644
--- a/python/pyarmnn/src/pyarmnn/_version.py
+++ b/python/pyarmnn/src/pyarmnn/_version.py
@@ -3,7 +3,7 @@
# SPDX-License-Identifier: MIT
import os
-version_info = (21, 0, 0)
+version_info = (22, 0, 0)
__dev_version_env = os.getenv("PYARMNN_DEV_VER", "")
@@ -24,7 +24,7 @@ def check_armnn_version(installed_armnn_version: str, expected_armnn_version: st
"""Compares expected Arm NN version and Arm NN version used to build the package.
Args:
installed_armnn_version (str): Arm NN version used to generate the package (e.g. 21.0.0)
expected_armnn_version (str): Expected Arm NN version
Returns:
@@ -24,7 +24,7 @@ def check_armnn_version(installed_armnn_version: str, expected_armnn_version: st
"""Compares expected Arm NN version and Arm NN version used to build the package.
Args:
- installed_armnn_version (str): Arm NN version used to generate the package (e.g. 21.0.0)
+ installed_armnn_version (str): Arm NN version used to generate the package (e.g. 22.0.0)
expected_armnn_version (str): Expected Arm NN version
Returns: